fix_rectificationMatrix_param {#master}
-----------------------------

## Libraries

### `sig`

#### `IntrinsicParams`

* Deprecate `YARP_PLUM_BOB` in favour of `YARP_PLUMB_BOB`



### `dev`

#### `IDepthVisualParams`

* The `retificationMatrix` parameter was renamed `rectificationMatrix`

#### `IRgbVisualParams`

* The `retificationMatrix` parameter was renamed `rectificationMatrix`
